@@ -282,7 +282,7 @@ def _type_convert(dtype):
     else:
         raise ValueError('Unkwnown type: {}'.format(str(dtype)))
 
-class RollMultiLayerShortCutLSTM(MultiLayerShortCutLSTM, roller._RollingBasis):
+class RollMultiLayerShortCutLSTM(MultiLayerShortCutLSTM, roller._ShortCutRollingBasis):
     """ Rolling version of the vanilla neural network model.
     TODO:
     - fix train and predict methods
